<?php
/**
 * TP Philosophy Pro our teams customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add our teams template section
$wp_customize->add_section( 'tp_philosophy_pro_our_teams_section', array(
	'title'             => esc_html__( 'Our Teams Members','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Our teams member options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_our_team_template_panel'
) );


// Add our teams option heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[team_options_heading]', array(
	'label'           	=> esc_html__( 'Team Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_our_teams_section',
	'type'				=> 'description',
) ) );

// Add enable team options setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[enable_team_options]', array(
	'default'           => $options['enable_team_options'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[enable_team_options]', array(
	'label'             => esc_html__( 'Enable Teams Options.', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_our_teams_section',
	'type'              => 'checkbox',
) );

// Add team_options custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_custom_title]',array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['team_options_custom_title'],
) );
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[team_options_custom_title]',array(
	'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Enter Title.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_our_teams_section',
    'active_callback'		=> 'tp_philosophy_pro_is_team_options_enabled',
) );

// Add team_options section sub title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_subtitle]', array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['team_options_subtitle'],
) );
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[team_options_subtitle]', array(
	'label'      			=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Enter subtitle.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_our_teams_section',
	'active_callback' 		=> 'tp_philosophy_pro_is_team_options_enabled',	
) );

// Add team options section custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_custom_description]', array(
	'sanitize_callback'		=> 'esc_textarea',
	'default' 				=> $options['team_options_custom_description'],
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[team_options_custom_description]', array(
	'label'      			=> esc_html__( 'Description', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Input description.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_our_teams_section',
	'type'		 			=> 'textarea',
	'active_callback' 		=> 'tp_philosophy_pro_is_team_options_enabled',	
) );

// Add team options content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_content_type]', array(
	'default'           => $options['team_options_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

if ( ! class_exists( 'TP_Philosophy_Tools' ) ) {
    $content_type_description = esc_html__( 'Team Option requires', 'tp-philosophy-pro' ) . sprintf( '<a target="_blank" href="%s"> %s </a>', esc_url( 'https://wordpress.org/plugins/tp-philosophy-teams/' ), esc_html__( 'TP Philosophy Tools Plugin', 'tp-philosophy-pro' ) );

	$choices = array(
		'category'            => esc_html__( 'Default Category', 'tp-philosophy-pro' ),
	);
} else{
    $content_type_description = '';
    $choices = array(
		'category'            => esc_html__( 'Default Category', 'tp-philosophy-pro' ),
		'tp-philosophy-teams' => esc_html__( 'Plugin Team Taxonomy.', 'tp-philosophy-pro' ),
	);
}
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[team_options_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description' 		=> $content_type_description,
	'section'         	=> 'tp_philosophy_pro_our_teams_section',
	'type'            	=> 'select',
	'active_callback' 		=> 'tp_philosophy_pro_is_team_options_enabled',	
	'choices'         	=> $choices
) );

// Add category type setting and control
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[team_options_content_category]', array(
  	'sanitize_callback' => 'tp_philosophy_pro_sanitize_muti_select_categories_list',
) ) ;

$wp_customize->add_control( new Tp_Philosophy_Pro_Multi_Select_Categories_Control ( $wp_customize,'tp_philosophy_pro_theme_options[team_options_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'tp-philosophy-pro' ),
	'description'     => esc_html__( 'Team members from selected category will be shown.', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_our_teams_section',
	'active_callback'   => 'tp_philosophy_pro_team_options_content_category_active'
) ) );

// Taxonomy Content Type
$wp_customize->add_setting(  'tp_philosophy_pro_theme_options[team_options_custom_taxonomy]', array(
  'sanitize_callback' => 'tp_philosophy_pro_sanitize_multi_select_taxonomies_control',
) ) ;

$wp_customize->add_control( new Tp_Philosophy_Pro_Multi_Select_Taxonomies_Control ( $wp_customize,'tp_philosophy_pro_theme_options[team_options_custom_taxonomy]', array(
  'label'             => esc_html__( 'Select Terms', 'tp-philosophy-pro' ),
  'section'           => 'tp_philosophy_pro_our_teams_section',
  'taxonomy'          => 'tp-philosophy-teams-category',
  'type'              => 'dropdown-taxonomies',
  'active_callback'   => 'tp_philosophy_pro_team_options_custom_taxonomy_active'
) ) );


/**
 *
 * Join our team section
 *
 * @since 1.0
 *
 */

// Add our teams template section
$wp_customize->add_section( 'tp_philosophy_pro_join_our_teams_section', array(
	'title'             => esc_html__( 'Join Our Teams','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Join our team options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_our_team_template_panel'
) );


// Add join team heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[join_team_heading]', array(
	'label'           	=> esc_html__( 'Join Team Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_join_our_teams_section',
	'type'				=> 'description',
) ) );

// Add enable join team options setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[enable_join_team_section]', array(
	'default'           => $options['enable_join_team_section'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[enable_join_team_section]', array(
	'label'             => esc_html__( 'Enable Join Team Options.', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_join_our_teams_section',
	'type'              => 'checkbox',
) );

// Add join team content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_content_type]', array(
	'default' 			=> $options['join_team_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description'       => esc_html__( 'Select content from.', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_join_our_teams_section',
	'type'            	=> 'select',
	'choices'         	=> array(
		'post' 			=> esc_html__( 'Post', 'tp-philosophy-pro' ),
		'page' 			=> esc_html__( 'Page', 'tp-philosophy-pro' ),
		'custom' 		=> esc_html__( 'Custom content', 'tp-philosophy-pro' ),
	),
	'active_callback' 	=> 'tp_philosophy_pro_is_join_team_options_enabled',	
) );

// Add setting and controls to input post id

$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_post_id]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_post_id]', array(
	'label'           => esc_html__( 'Enter Post ID', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_join_our_teams_section',
	'input_attrs' 		=> array( 
		'style' 		=> 'width: 100px;',
		'min'			=> '1', 
		'placeholder'	=> esc_attr__( 'Post ID', 'tp-philosophy-pro' ) ),
	'type'              => 'number',
	'active_callback' => 'tp_philosophy_pro_is_join_content_post_active',
) );

// Add setting and controls to input page id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_page_id]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_page'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_page_id]', array(
	'label'             => esc_html__( 'Select Page' , 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_join_our_teams_section',
	'active_callback'	=> 'tp_philosophy_pro_is_join_content_page_active',
	'type'              => 'dropdown-pages',
) );


// Add join team options custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_custom_title]',array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['join_team_custom_title'],
) );
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_custom_title]',array(
	'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Enter Title.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_join_our_teams_section',
    'active_callback'		=> 'tp_philosophy_pro_is_join_content_custom_active',
) );

// Add join team section sub title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_subtitle]', array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['join_team_subtitle'],
) );
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_subtitle]', array(
	'label'      			=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Enter subtitle.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_join_our_teams_section',
	'active_callback' 		=> 'tp_philosophy_pro_is_join_team_options_enabled',	
) );

// Add join team section custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_custom_description]', array(
	'sanitize_callback'		=> 'esc_textarea',
	'default' 				=> $options['join_team_custom_description'],
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_custom_description]', array(
	'label'      			=> esc_html__( 'Description', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Input description.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_join_our_teams_section',
	'type'		 			=> 'textarea',
	'active_callback' 		=> 'tp_philosophy_pro_is_join_content_custom_active',	
) );

// Add join team section custom content
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_custom_blogquote]', array(
	'sanitize_callback'		=> 'esc_textarea',
	'default' 				=> $options['join_team_custom_blogquote'],
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_custom_blogquote]', array(
	'label'      			=> esc_html__( 'Blogquote', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Input blogquote. &lt;a&gt; tag is allowed.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_join_our_teams_section',
	'type'		 			=> 'textarea',
	'active_callback' 		=> 'tp_philosophy_pro_is_join_team_options_enabled',	
) );

// Add custom image setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_custom_image]', array(
	'default'           => $options['join_team_custom_image'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tp_philosophy_pro_theme_options[join_team_custom_image]',
    array(
		'label'           => esc_html__( 'Upload image', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Recommended slide image size is 585x605 px', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_join_our_teams_section',
		'active_callback' => 'tp_philosophy_pro_is_join_content_custom_active',
    )
) );

// Add custom link setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[join_team_custom_link]', array(
	'default'           => $options['join_team_custom_link'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[join_team_custom_link]', array(
		'label'           	=> esc_html__( 'Link', 'tp-philosophy-pro' ),
		'description'		=> esc_html__( 'Input link', 'tp-philosophy-pro' ),
		'section'         	=> 'tp_philosophy_pro_join_our_teams_section',
		'type'				=> 'url',
		'active_callback' 	=> 'tp_philosophy_pro_is_join_content_custom_active',
) );
	